# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DeviceMigrationPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'source': 'str',
        'target': 'str',
        'transfer_size': 'int',
        'paused': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'source': 'source',
        'target': 'target',
        'transfer_size': 'transfer_size',
        'paused': 'paused'
    }

    def __init__(self, name=None, source=None, target=None, transfer_size=None, paused=None):  # noqa: E501
        """DeviceMigrationPayload - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._source = None
        self._target = None
        self._transfer_size = None
        self._paused = None
        self.discriminator = None

        self.name = name
        self.source = source
        self.target = target
        if transfer_size is not None:
            self.transfer_size = transfer_size
        if paused is not None:
            self.paused = paused

    @property
    def name(self):
        """Gets the name of this DeviceMigrationPayload.  # noqa: E501


        :return: The name of this DeviceMigrationPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceMigrationPayload.


        :param name: The name of this DeviceMigrationPayload.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def source(self):
        """Gets the source of this DeviceMigrationPayload.  # noqa: E501


        :return: The source of this DeviceMigrationPayload.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DeviceMigrationPayload.


        :param source: The source of this DeviceMigrationPayload.  # noqa: E501
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def target(self):
        """Gets the target of this DeviceMigrationPayload.  # noqa: E501


        :return: The target of this DeviceMigrationPayload.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this DeviceMigrationPayload.


        :param target: The target of this DeviceMigrationPayload.  # noqa: E501
        :type: str
        """
        if target is None:
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    @property
    def transfer_size(self):
        """Gets the transfer_size of this DeviceMigrationPayload.  # noqa: E501

        Number in Byte. Must be a multiple of 4K. Range: 40KB - 128M. Default: 128KB(131072).   # noqa: E501

        :return: The transfer_size of this DeviceMigrationPayload.  # noqa: E501
        :rtype: int
        """
        return self._transfer_size

    @transfer_size.setter
    def transfer_size(self, transfer_size):
        """Sets the transfer_size of this DeviceMigrationPayload.

        Number in Byte. Must be a multiple of 4K. Range: 40KB - 128M. Default: 128KB(131072).   # noqa: E501

        :param transfer_size: The transfer_size of this DeviceMigrationPayload.  # noqa: E501
        :type: int
        """

        self._transfer_size = transfer_size

    @property
    def paused(self):
        """Gets the paused of this DeviceMigrationPayload.  # noqa: E501


        :return: The paused of this DeviceMigrationPayload.  # noqa: E501
        :rtype: bool
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this DeviceMigrationPayload.


        :param paused: The paused of this DeviceMigrationPayload.  # noqa: E501
        :type: bool
        """

        self._paused = paused

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceMigrationPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vplexapi.api_client import ApiClient


class DistributedStorageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_distributed_consistency_group(self, distributed_consistency_group_payload, **kwargs):  # noqa: E501
        """Create a new distributed ConsistencyGroup  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_distributed_consistency_group(distributed_consistency_group_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DistributedConsistencyGroupPayload distributed_consistency_group_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_distributed_consistency_group_with_http_info(distributed_consistency_group_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.create_distributed_consistency_group_with_http_info(distributed_consistency_group_payload, **kwargs)  # noqa: E501
            return data

    def create_distributed_consistency_group_with_http_info(self, distributed_consistency_group_payload, **kwargs):  # noqa: E501
        """Create a new distributed ConsistencyGroup  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_distributed_consistency_group_with_http_info(distributed_consistency_group_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DistributedConsistencyGroupPayload distributed_consistency_group_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['distributed_consistency_group_payload', 'x_include_object']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_distributed_consistency_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'distributed_consistency_group_payload' is set
        if ('distributed_consistency_group_payload' not in params or
                params['distributed_consistency_group_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_consistency_group_payload` when calling `create_distributed_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_include_object' in params:
            header_params['X-Include-Object'] = params['x_include_object']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_consistency_group_payload' in params:
            body_params = params['distributed_consistency_group_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_consistency_groups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConsistencyGroup',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_distributed_device(self, distributed_device_payload, **kwargs):  # noqa: E501
        """Create a new DistributedDevice  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_distributed_device(distributed_device_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DistributedDevicePayload distributed_device_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_distributed_device_with_http_info(distributed_device_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.create_distributed_device_with_http_info(distributed_device_payload, **kwargs)  # noqa: E501
            return data

    def create_distributed_device_with_http_info(self, distributed_device_payload, **kwargs):  # noqa: E501
        """Create a new DistributedDevice  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_distributed_device_with_http_info(distributed_device_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DistributedDevicePayload distributed_device_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['distributed_device_payload', 'x_include_object']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_distributed_device" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'distributed_device_payload' is set
        if ('distributed_device_payload' not in params or
                params['distributed_device_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_device_payload` when calling `create_distributed_device`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_include_object' in params:
            header_params['X-Include-Object'] = params['x_include_object']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_device_payload' in params:
            body_params = params['distributed_device_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_devices', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DistributedDevice',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_distributed_virtual_volume(self, distributed_virtual_volume_payload, **kwargs):  # noqa: E501
        """Create a new distributed VirtualVolume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_distributed_virtual_volume(distributed_virtual_volume_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DistributedVirtualVolumePayload distributed_virtual_volume_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_distributed_virtual_volume_with_http_info(distributed_virtual_volume_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.create_distributed_virtual_volume_with_http_info(distributed_virtual_volume_payload, **kwargs)  # noqa: E501
            return data

    def create_distributed_virtual_volume_with_http_info(self, distributed_virtual_volume_payload, **kwargs):  # noqa: E501
        """Create a new distributed VirtualVolume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_distributed_virtual_volume_with_http_info(distributed_virtual_volume_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DistributedVirtualVolumePayload distributed_virtual_volume_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['distributed_virtual_volume_payload', 'x_include_object']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_distributed_virtual_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'distributed_virtual_volume_payload' is set
        if ('distributed_virtual_volume_payload' not in params or
                params['distributed_virtual_volume_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_virtual_volume_payload` when calling `create_distributed_virtual_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_include_object' in params:
            header_params['X-Include-Object'] = params['x_include_object']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_virtual_volume_payload' in params:
            body_params = params['distributed_virtual_volume_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_virtual_volumes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VirtualVolume',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_distributed_consistency_group(self, name, **kwargs):  # noqa: E501
        """Deletes a single distributed ConsistencyGroup  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_distributed_consistency_group(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_distributed_consistency_group_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_distributed_consistency_group_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_distributed_consistency_group_with_http_info(self, name, **kwargs):  # noqa: E501
        """Deletes a single distributed ConsistencyGroup  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_distributed_consistency_group_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_distributed_consistency_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_distributed_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_consistency_groups/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_distributed_device(self, name, **kwargs):  # noqa: E501
        """Deletes a single DistributedDevice  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_distributed_device(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_distributed_device_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_distributed_device_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_distributed_device_with_http_info(self, name, **kwargs):  # noqa: E501
        """Deletes a single DistributedDevice  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_distributed_device_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_distributed_device" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_distributed_device`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_devices/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_distributed_virtual_volume(self, name, **kwargs):  # noqa: E501
        """Deletes a single distributed VirtualVolume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_distributed_virtual_volume(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_distributed_virtual_volume_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_distributed_virtual_volume_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_distributed_virtual_volume_with_http_info(self, name, **kwargs):  # noqa: E501
        """Deletes a single distributed VirtualVolume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_distributed_virtual_volume_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_distributed_virtual_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_distributed_virtual_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_virtual_volumes/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def expand_distributed_virtual_volume(self, name, distributed_virtual_volume_expand_payload, **kwargs):  # noqa: E501
        """Expand the capacity of a distributed VirtualVolume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.expand_distributed_virtual_volume(name, distributed_virtual_volume_expand_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param DistributedVirtualVolumeExpandPayload distributed_virtual_volume_expand_payload: (required)
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.expand_distributed_virtual_volume_with_http_info(name, distributed_virtual_volume_expand_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.expand_distributed_virtual_volume_with_http_info(name, distributed_virtual_volume_expand_payload, **kwargs)  # noqa: E501
            return data

    def expand_distributed_virtual_volume_with_http_info(self, name, distributed_virtual_volume_expand_payload, **kwargs):  # noqa: E501
        """Expand the capacity of a distributed VirtualVolume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.expand_distributed_virtual_volume_with_http_info(name, distributed_virtual_volume_expand_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param DistributedVirtualVolumeExpandPayload distributed_virtual_volume_expand_payload: (required)
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'distributed_virtual_volume_expand_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method expand_distributed_virtual_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `expand_distributed_virtual_volume`")  # noqa: E501
        # verify the required parameter 'distributed_virtual_volume_expand_payload' is set
        if ('distributed_virtual_volume_expand_payload' not in params or
                params['distributed_virtual_volume_expand_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_virtual_volume_expand_payload` when calling `expand_distributed_virtual_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_virtual_volume_expand_payload' in params:
            body_params = params['distributed_virtual_volume_expand_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_virtual_volumes/{name}/expand', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VirtualVolume',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_distributed_consistency_group(self, name, **kwargs):  # noqa: E501
        """Returns a single distributed ConsistencyGroup object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_consistency_group(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_distributed_consistency_group_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_distributed_consistency_group_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_distributed_consistency_group_with_http_info(self, name, **kwargs):  # noqa: E501
        """Returns a single distributed ConsistencyGroup object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_consistency_group_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_distributed_consistency_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_distributed_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_consistency_groups/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConsistencyGroup',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_distributed_consistency_groups(self, **kwargs):  # noqa: E501
        """Returns a list of distributed ConsistencyGroups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_consistency_groups(async=True)
        >>> result = thread.get()

        :param async bool
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str operational_status: Filter results by operational_status. See LexicalQueryExpression for details.
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[ConsistencyGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_distributed_consistency_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_distributed_consistency_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_distributed_consistency_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of distributed ConsistencyGroups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_consistency_groups_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str operational_status: Filter results by operational_status. See LexicalQueryExpression for details.
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[ConsistencyGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'name', 'operational_status', 'sort_by', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_distributed_consistency_groups" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_distributed_consistency_groups`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_distributed_consistency_groups`, must be a value less than or equal to `100`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_distributed_consistency_groups`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'operational_status' in params:
            query_params.append(('operational_status', params['operational_status']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sort_by', params['sort_by']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_consistency_groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ConsistencyGroup]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_distributed_device(self, name, **kwargs):  # noqa: E501
        """Returns a single DistributedDevice object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_device(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_distributed_device_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_distributed_device_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_distributed_device_with_http_info(self, name, **kwargs):  # noqa: E501
        """Returns a single DistributedDevice object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_device_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_distributed_device" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_distributed_device`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_devices/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DistributedDevice',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_distributed_devices(self, **kwargs):  # noqa: E501
        """Returns a list of DistributedDevices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_devices(async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str capacity: Filter results by capacity.  See NumericQueryExpression for details.
        :param str thin_capable: Filter results by thin_capable.  See LexicalQueryExpression for details.
        :param str health_state: Filter results by health_state. See LexicalQueryExpression for details.
        :param str operational_status: Filter results by operational_status. See LexicalQueryExpression for details.
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[DistributedDevice]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_distributed_devices_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_distributed_devices_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_distributed_devices_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of DistributedDevices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_devices_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str capacity: Filter results by capacity.  See NumericQueryExpression for details.
        :param str thin_capable: Filter results by thin_capable.  See LexicalQueryExpression for details.
        :param str health_state: Filter results by health_state. See LexicalQueryExpression for details.
        :param str operational_status: Filter results by operational_status. See LexicalQueryExpression for details.
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[DistributedDevice]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'capacity', 'thin_capable', 'health_state', 'operational_status', 'offset', 'limit', 'sort_by', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_distributed_devices" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_distributed_devices`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_distributed_devices`, must be a value less than or equal to `100`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_distributed_devices`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'capacity' in params:
            query_params.append(('capacity', params['capacity']))  # noqa: E501
        if 'thin_capable' in params:
            query_params.append(('thin_capable', params['thin_capable']))  # noqa: E501
        if 'health_state' in params:
            query_params.append(('health_state', params['health_state']))  # noqa: E501
        if 'operational_status' in params:
            query_params.append(('operational_status', params['operational_status']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sort_by', params['sort_by']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_devices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DistributedDevice]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_distributed_virtual_volume(self, name, **kwargs):  # noqa: E501
        """Returns a single distributed VirtualVolume object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_virtual_volume(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_distributed_virtual_volume_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_distributed_virtual_volume_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_distributed_virtual_volume_with_http_info(self, name, **kwargs):  # noqa: E501
        """Returns a single distributed VirtualVolume object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_virtual_volume_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_distributed_virtual_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_distributed_virtual_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_virtual_volumes/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VirtualVolume',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_distributed_virtual_volumes(self, **kwargs):  # noqa: E501
        """Returns a list of distributed VirtualVolumes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_virtual_volumes(async=True)
        >>> result = thread.get()

        :param async bool
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str capacity: Filter results by capacity.  See NumericQueryExpression for details.
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :param str consistency_group: Filter results by consistency_group. See LexicalQueryExpression for details.
        :param str health_state: Filter results by health_state. See LexicalQueryExpression for details.
        :param str operational_status: Filter results by operational_status. See LexicalQueryExpression for details.
        :param str service_status: Filter results by service_status. See LexicalQueryExpression for details.
        :param str thin_enabled: Filter results by thin_enabled. See LexicalQueryExpression for details.
        :return: list[VirtualVolume]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_distributed_virtual_volumes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_distributed_virtual_volumes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_distributed_virtual_volumes_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of distributed VirtualVolumes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_distributed_virtual_volumes_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str capacity: Filter results by capacity.  See NumericQueryExpression for details.
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :param str consistency_group: Filter results by consistency_group. See LexicalQueryExpression for details.
        :param str health_state: Filter results by health_state. See LexicalQueryExpression for details.
        :param str operational_status: Filter results by operational_status. See LexicalQueryExpression for details.
        :param str service_status: Filter results by service_status. See LexicalQueryExpression for details.
        :param str thin_enabled: Filter results by thin_enabled. See LexicalQueryExpression for details.
        :return: list[VirtualVolume]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'name', 'capacity', 'sort_by', 'fields', 'consistency_group', 'health_state', 'operational_status', 'service_status', 'thin_enabled']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_distributed_virtual_volumes" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_distributed_virtual_volumes`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_distributed_virtual_volumes`, must be a value less than or equal to `100`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_distributed_virtual_volumes`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'capacity' in params:
            query_params.append(('capacity', params['capacity']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sort_by', params['sort_by']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
        if 'consistency_group' in params:
            query_params.append(('consistency_group', params['consistency_group']))  # noqa: E501
        if 'health_state' in params:
            query_params.append(('health_state', params['health_state']))  # noqa: E501
        if 'operational_status' in params:
            query_params.append(('operational_status', params['operational_status']))  # noqa: E501
        if 'service_status' in params:
            query_params.append(('service_status', params['service_status']))  # noqa: E501
        if 'thin_enabled' in params:
            query_params.append(('thin_enabled', params['thin_enabled']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_virtual_volumes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[VirtualVolume]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_rule_set(self, name, **kwargs):  # noqa: E501
        """Returns a single RuleSet object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_rule_set(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: RuleSet
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_rule_set_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_rule_set_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_rule_set_with_http_info(self, name, **kwargs):  # noqa: E501
        """Returns a single RuleSet object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_rule_set_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: RuleSet
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_rule_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_rule_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/rule_sets/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RuleSet',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_rule_sets(self, **kwargs):  # noqa: E501
        """Returns a list of RuleSets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_rule_sets(async=True)
        >>> result = thread.get()

        :param async bool
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :return: list[RuleSet]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_rule_sets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_rule_sets_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_rule_sets_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of RuleSets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_rule_sets_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :return: list[RuleSet]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_rule_sets" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_rule_sets`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_rule_sets`, must be a value less than or equal to `100`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_rule_sets`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/rule_sets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RuleSet]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_distributed_consistency_group(self, name, distributed_consistency_group_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a distributed ConsistencyGroup  # noqa: E501

        Patchable attributes are 'storage_at_clusters' (add/remove), 'virtual_volumes' (add/remove), 'visibility' (add/remove), 'name', 'recoverpoint_enabled', 'auto_resume_at_loser' and 'detach_rule'   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_distributed_consistency_group(name, distributed_consistency_group_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] distributed_consistency_group_patch_payload: (required)
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.patch_distributed_consistency_group_with_http_info(name, distributed_consistency_group_patch_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_distributed_consistency_group_with_http_info(name, distributed_consistency_group_patch_payload, **kwargs)  # noqa: E501
            return data

    def patch_distributed_consistency_group_with_http_info(self, name, distributed_consistency_group_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a distributed ConsistencyGroup  # noqa: E501

        Patchable attributes are 'storage_at_clusters' (add/remove), 'virtual_volumes' (add/remove), 'visibility' (add/remove), 'name', 'recoverpoint_enabled', 'auto_resume_at_loser' and 'detach_rule'   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_distributed_consistency_group_with_http_info(name, distributed_consistency_group_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] distributed_consistency_group_patch_payload: (required)
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'distributed_consistency_group_patch_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_distributed_consistency_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `patch_distributed_consistency_group`")  # noqa: E501
        # verify the required parameter 'distributed_consistency_group_patch_payload' is set
        if ('distributed_consistency_group_patch_payload' not in params or
                params['distributed_consistency_group_patch_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_consistency_group_patch_payload` when calling `patch_distributed_consistency_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_consistency_group_patch_payload' in params:
            body_params = params['distributed_consistency_group_patch_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_consistency_groups/{name}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConsistencyGroup',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_distributed_device(self, name, distributed_device_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a DistributedDevice  # noqa: E501

        Settable attributes: 'name', 'legs', 'transfer_size', 'rule_set_name'   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_distributed_device(name, distributed_device_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] distributed_device_patch_payload: (required)
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.patch_distributed_device_with_http_info(name, distributed_device_patch_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_distributed_device_with_http_info(name, distributed_device_patch_payload, **kwargs)  # noqa: E501
            return data

    def patch_distributed_device_with_http_info(self, name, distributed_device_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a DistributedDevice  # noqa: E501

        Settable attributes: 'name', 'legs', 'transfer_size', 'rule_set_name'   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_distributed_device_with_http_info(name, distributed_device_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] distributed_device_patch_payload: (required)
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'distributed_device_patch_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_distributed_device" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `patch_distributed_device`")  # noqa: E501
        # verify the required parameter 'distributed_device_patch_payload' is set
        if ('distributed_device_patch_payload' not in params or
                params['distributed_device_patch_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_device_patch_payload` when calling `patch_distributed_device`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_device_patch_payload' in params:
            body_params = params['distributed_device_patch_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_devices/{name}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DistributedDevice',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_distributed_virtual_volume(self, name, distributed_virtual_volume_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a distributed VirtualVolume  # noqa: E501

        Settable attributes: 'name'   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_distributed_virtual_volume(name, distributed_virtual_volume_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] distributed_virtual_volume_patch_payload: (required)
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.patch_distributed_virtual_volume_with_http_info(name, distributed_virtual_volume_patch_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_distributed_virtual_volume_with_http_info(name, distributed_virtual_volume_patch_payload, **kwargs)  # noqa: E501
            return data

    def patch_distributed_virtual_volume_with_http_info(self, name, distributed_virtual_volume_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a distributed VirtualVolume  # noqa: E501

        Settable attributes: 'name'   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_distributed_virtual_volume_with_http_info(name, distributed_virtual_volume_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] distributed_virtual_volume_patch_payload: (required)
        :return: VirtualVolume
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'distributed_virtual_volume_patch_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_distributed_virtual_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `patch_distributed_virtual_volume`")  # noqa: E501
        # verify the required parameter 'distributed_virtual_volume_patch_payload' is set
        if ('distributed_virtual_volume_patch_payload' not in params or
                params['distributed_virtual_volume_patch_payload'] is None):
            raise ValueError("Missing the required parameter `distributed_virtual_volume_patch_payload` when calling `patch_distributed_virtual_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'distributed_virtual_volume_patch_payload' in params:
            body_params = params['distributed_virtual_volume_patch_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_virtual_volumes/{name}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VirtualVolume',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume(self, name, cg_resume_payload, **kwargs):  # noqa: E501
        """Manually resume I/O to the virtual-volumes in a distributed consistency group.  In a cluster-partition scenario where the ruleset does not indicate an automatic winner, this endpoint will select the winning cluster where I/O should continue.  After a cluster-partition is resolved, in the case that auto-resume-at-loser is set to false, this endpoint will resume I/O on the losing cluster.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.resume(name, cg_resume_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param CgResumePayload cg_resume_payload: (required)
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.resume_with_http_info(name, cg_resume_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_with_http_info(name, cg_resume_payload, **kwargs)  # noqa: E501
            return data

    def resume_with_http_info(self, name, cg_resume_payload, **kwargs):  # noqa: E501
        """Manually resume I/O to the virtual-volumes in a distributed consistency group.  In a cluster-partition scenario where the ruleset does not indicate an automatic winner, this endpoint will select the winning cluster where I/O should continue.  After a cluster-partition is resolved, in the case that auto-resume-at-loser is set to false, this endpoint will resume I/O on the losing cluster.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.resume_with_http_info(name, cg_resume_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param CgResumePayload cg_resume_payload: (required)
        :return: ConsistencyGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'cg_resume_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `resume`")  # noqa: E501
        # verify the required parameter 'cg_resume_payload' is set
        if ('cg_resume_payload' not in params or
                params['cg_resume_payload'] is None):
            raise ValueError("Missing the required parameter `cg_resume_payload` when calling `resume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cg_resume_payload' in params:
            body_params = params['cg_resume_payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_consistency_groups/{name}/resume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConsistencyGroup',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_link_up(self, name, **kwargs):  # noqa: E501
        """Manually resume I/O to a distributed device that supports a distributed virtual-volume.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.resume_link_up(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.resume_link_up_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_link_up_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def resume_link_up_with_http_info(self, name, **kwargs):  # noqa: E501
        """Manually resume I/O to a distributed device that supports a distributed virtual-volume.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.resume_link_up_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: DistributedDevice
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_link_up" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `resume_link_up`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/distributed_storage/distributed_devices/{name}/resume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DistributedDevice',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.communication_status import CommunicationStatus  # noqa: F401,E501
from vplexapi.models.health_state import HealthState  # noqa: F401,E501
from vplexapi.models.operational_status import OperationalStatus  # noqa: F401,E501


class Director(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_boot': 'bool',
        'auto_restart': 'bool',
        'cluster_id': 'int',
        'communication_status': 'CommunicationStatus',
        'director_count': 'int',
        'director_family': 'str',
        'director_id': 'str',
        'director_type': 'str',
        'engine_id': 'str',
        'firmware_uptime': 'int',
        'health_indications': 'list[str]',
        'health_state': 'HealthState',
        'hostname': 'str',
        'name': 'str',
        'operational_status': 'OperationalStatus',
        'os_uptime': 'int',
        'port': 'int',
        'serial_number': 'str',
        'system_time': 'str',
        'temperature_threshold_exceeded': 'bool',
        'voltage_threshold_exceeded': 'bool',
        'vplex_kdriver_status': 'str'
    }

    attribute_map = {
        'auto_boot': 'auto_boot',
        'auto_restart': 'auto_restart',
        'cluster_id': 'cluster_id',
        'communication_status': 'communication_status',
        'director_count': 'director_count',
        'director_family': 'director_family',
        'director_id': 'director_id',
        'director_type': 'director_type',
        'engine_id': 'engine_id',
        'firmware_uptime': 'firmware_uptime',
        'health_indications': 'health_indications',
        'health_state': 'health_state',
        'hostname': 'hostname',
        'name': 'name',
        'operational_status': 'operational_status',
        'os_uptime': 'os_uptime',
        'port': 'port',
        'serial_number': 'serial_number',
        'system_time': 'system_time',
        'temperature_threshold_exceeded': 'temperature_threshold_exceeded',
        'voltage_threshold_exceeded': 'voltage_threshold_exceeded',
        'vplex_kdriver_status': 'vplex_kdriver_status'
    }

    def __init__(self, auto_boot=None, auto_restart=None, cluster_id=None, communication_status=None, director_count=None, director_family=None, director_id=None, director_type=None, engine_id=None, firmware_uptime=None, health_indications=None, health_state=None, hostname=None, name=None, operational_status=None, os_uptime=None, port=None, serial_number=None, system_time=None, temperature_threshold_exceeded=None, voltage_threshold_exceeded=None, vplex_kdriver_status=None):  # noqa: E501
        """Director - a model defined in Swagger"""  # noqa: E501

        self._auto_boot = None
        self._auto_restart = None
        self._cluster_id = None
        self._communication_status = None
        self._director_count = None
        self._director_family = None
        self._director_id = None
        self._director_type = None
        self._engine_id = None
        self._firmware_uptime = None
        self._health_indications = None
        self._health_state = None
        self._hostname = None
        self._name = None
        self._operational_status = None
        self._os_uptime = None
        self._port = None
        self._serial_number = None
        self._system_time = None
        self._temperature_threshold_exceeded = None
        self._voltage_threshold_exceeded = None
        self._vplex_kdriver_status = None
        self.discriminator = None

        if auto_boot is not None:
            self.auto_boot = auto_boot
        if auto_restart is not None:
            self.auto_restart = auto_restart
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if communication_status is not None:
            self.communication_status = communication_status
        if director_count is not None:
            self.director_count = director_count
        if director_family is not None:
            self.director_family = director_family
        if director_id is not None:
            self.director_id = director_id
        if director_type is not None:
            self.director_type = director_type
        if engine_id is not None:
            self.engine_id = engine_id
        if firmware_uptime is not None:
            self.firmware_uptime = firmware_uptime
        if health_indications is not None:
            self.health_indications = health_indications
        if health_state is not None:
            self.health_state = health_state
        if hostname is not None:
            self.hostname = hostname
        if name is not None:
            self.name = name
        if operational_status is not None:
            self.operational_status = operational_status
        if os_uptime is not None:
            self.os_uptime = os_uptime
        if port is not None:
            self.port = port
        if serial_number is not None:
            self.serial_number = serial_number
        if system_time is not None:
            self.system_time = system_time
        if temperature_threshold_exceeded is not None:
            self.temperature_threshold_exceeded = temperature_threshold_exceeded
        if voltage_threshold_exceeded is not None:
            self.voltage_threshold_exceeded = voltage_threshold_exceeded
        if vplex_kdriver_status is not None:
            self.vplex_kdriver_status = vplex_kdriver_status

    @property
    def auto_boot(self):
        """Gets the auto_boot of this Director.  # noqa: E501


        :return: The auto_boot of this Director.  # noqa: E501
        :rtype: bool
        """
        return self._auto_boot

    @auto_boot.setter
    def auto_boot(self, auto_boot):
        """Sets the auto_boot of this Director.


        :param auto_boot: The auto_boot of this Director.  # noqa: E501
        :type: bool
        """

        self._auto_boot = auto_boot

    @property
    def auto_restart(self):
        """Gets the auto_restart of this Director.  # noqa: E501


        :return: The auto_restart of this Director.  # noqa: E501
        :rtype: bool
        """
        return self._auto_restart

    @auto_restart.setter
    def auto_restart(self, auto_restart):
        """Sets the auto_restart of this Director.


        :param auto_restart: The auto_restart of this Director.  # noqa: E501
        :type: bool
        """

        self._auto_restart = auto_restart

    @property
    def cluster_id(self):
        """Gets the cluster_id of this Director.  # noqa: E501


        :return: The cluster_id of this Director.  # noqa: E501
        :rtype: int
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this Director.


        :param cluster_id: The cluster_id of this Director.  # noqa: E501
        :type: int
        """

        self._cluster_id = cluster_id

    @property
    def communication_status(self):
        """Gets the communication_status of this Director.  # noqa: E501


        :return: The communication_status of this Director.  # noqa: E501
        :rtype: CommunicationStatus
        """
        return self._communication_status

    @communication_status.setter
    def communication_status(self, communication_status):
        """Sets the communication_status of this Director.


        :param communication_status: The communication_status of this Director.  # noqa: E501
        :type: CommunicationStatus
        """

        self._communication_status = communication_status

    @property
    def director_count(self):
        """Gets the director_count of this Director.  # noqa: E501


        :return: The director_count of this Director.  # noqa: E501
        :rtype: int
        """
        return self._director_count

    @director_count.setter
    def director_count(self, director_count):
        """Sets the director_count of this Director.


        :param director_count: The director_count of this Director.  # noqa: E501
        :type: int
        """

        self._director_count = director_count

    @property
    def director_family(self):
        """Gets the director_family of this Director.  # noqa: E501


        :return: The director_family of this Director.  # noqa: E501
        :rtype: str
        """
        return self._director_family

    @director_family.setter
    def director_family(self, director_family):
        """Sets the director_family of this Director.


        :param director_family: The director_family of this Director.  # noqa: E501
        :type: str
        """

        self._director_family = director_family

    @property
    def director_id(self):
        """Gets the director_id of this Director.  # noqa: E501


        :return: The director_id of this Director.  # noqa: E501
        :rtype: str
        """
        return self._director_id

    @director_id.setter
    def director_id(self, director_id):
        """Sets the director_id of this Director.


        :param director_id: The director_id of this Director.  # noqa: E501
        :type: str
        """

        self._director_id = director_id

    @property
    def director_type(self):
        """Gets the director_type of this Director.  # noqa: E501


        :return: The director_type of this Director.  # noqa: E501
        :rtype: str
        """
        return self._director_type

    @director_type.setter
    def director_type(self, director_type):
        """Sets the director_type of this Director.


        :param director_type: The director_type of this Director.  # noqa: E501
        :type: str
        """

        self._director_type = director_type

    @property
    def engine_id(self):
        """Gets the engine_id of this Director.  # noqa: E501


        :return: The engine_id of this Director.  # noqa: E501
        :rtype: str
        """
        return self._engine_id

    @engine_id.setter
    def engine_id(self, engine_id):
        """Sets the engine_id of this Director.


        :param engine_id: The engine_id of this Director.  # noqa: E501
        :type: str
        """

        self._engine_id = engine_id

    @property
    def firmware_uptime(self):
        """Gets the firmware_uptime of this Director.  # noqa: E501


        :return: The firmware_uptime of this Director.  # noqa: E501
        :rtype: int
        """
        return self._firmware_uptime

    @firmware_uptime.setter
    def firmware_uptime(self, firmware_uptime):
        """Sets the firmware_uptime of this Director.


        :param firmware_uptime: The firmware_uptime of this Director.  # noqa: E501
        :type: int
        """

        self._firmware_uptime = firmware_uptime

    @property
    def health_indications(self):
        """Gets the health_indications of this Director.  # noqa: E501


        :return: The health_indications of this Director.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this Director.


        :param health_indications: The health_indications of this Director.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def health_state(self):
        """Gets the health_state of this Director.  # noqa: E501


        :return: The health_state of this Director.  # noqa: E501
        :rtype: HealthState
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this Director.


        :param health_state: The health_state of this Director.  # noqa: E501
        :type: HealthState
        """

        self._health_state = health_state

    @property
    def hostname(self):
        """Gets the hostname of this Director.  # noqa: E501


        :return: The hostname of this Director.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this Director.


        :param hostname: The hostname of this Director.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def name(self):
        """Gets the name of this Director.  # noqa: E501


        :return: The name of this Director.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Director.


        :param name: The name of this Director.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_status(self):
        """Gets the operational_status of this Director.  # noqa: E501


        :return: The operational_status of this Director.  # noqa: E501
        :rtype: OperationalStatus
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this Director.


        :param operational_status: The operational_status of this Director.  # noqa: E501
        :type: OperationalStatus
        """

        self._operational_status = operational_status

    @property
    def os_uptime(self):
        """Gets the os_uptime of this Director.  # noqa: E501


        :return: The os_uptime of this Director.  # noqa: E501
        :rtype: int
        """
        return self._os_uptime

    @os_uptime.setter
    def os_uptime(self, os_uptime):
        """Sets the os_uptime of this Director.


        :param os_uptime: The os_uptime of this Director.  # noqa: E501
        :type: int
        """

        self._os_uptime = os_uptime

    @property
    def port(self):
        """Gets the port of this Director.  # noqa: E501


        :return: The port of this Director.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this Director.


        :param port: The port of this Director.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def serial_number(self):
        """Gets the serial_number of this Director.  # noqa: E501


        :return: The serial_number of this Director.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this Director.


        :param serial_number: The serial_number of this Director.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def system_time(self):
        """Gets the system_time of this Director.  # noqa: E501


        :return: The system_time of this Director.  # noqa: E501
        :rtype: str
        """
        return self._system_time

    @system_time.setter
    def system_time(self, system_time):
        """Sets the system_time of this Director.


        :param system_time: The system_time of this Director.  # noqa: E501
        :type: str
        """

        self._system_time = system_time

    @property
    def temperature_threshold_exceeded(self):
        """Gets the temperature_threshold_exceeded of this Director.  # noqa: E501


        :return: The temperature_threshold_exceeded of this Director.  # noqa: E501
        :rtype: bool
        """
        return self._temperature_threshold_exceeded

    @temperature_threshold_exceeded.setter
    def temperature_threshold_exceeded(self, temperature_threshold_exceeded):
        """Sets the temperature_threshold_exceeded of this Director.


        :param temperature_threshold_exceeded: The temperature_threshold_exceeded of this Director.  # noqa: E501
        :type: bool
        """

        self._temperature_threshold_exceeded = temperature_threshold_exceeded

    @property
    def voltage_threshold_exceeded(self):
        """Gets the voltage_threshold_exceeded of this Director.  # noqa: E501


        :return: The voltage_threshold_exceeded of this Director.  # noqa: E501
        :rtype: bool
        """
        return self._voltage_threshold_exceeded

    @voltage_threshold_exceeded.setter
    def voltage_threshold_exceeded(self, voltage_threshold_exceeded):
        """Sets the voltage_threshold_exceeded of this Director.


        :param voltage_threshold_exceeded: The voltage_threshold_exceeded of this Director.  # noqa: E501
        :type: bool
        """

        self._voltage_threshold_exceeded = voltage_threshold_exceeded

    @property
    def vplex_kdriver_status(self):
        """Gets the vplex_kdriver_status of this Director.  # noqa: E501


        :return: The vplex_kdriver_status of this Director.  # noqa: E501
        :rtype: str
        """
        return self._vplex_kdriver_status

    @vplex_kdriver_status.setter
    def vplex_kdriver_status(self, vplex_kdriver_status):
        """Sets the vplex_kdriver_status of this Director.


        :param vplex_kdriver_status: The vplex_kdriver_status of this Director.  # noqa: E501
        :type: str
        """

        self._vplex_kdriver_status = vplex_kdriver_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Director):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Cluster(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'cluster_id': 'float',
        'island_id': 'float',
        'allow_auto_join': 'bool',
        'connected': 'bool',
        'top_level_assembly': 'str',
        'operational_status': 'str',
        'transition_indications': 'list[str]',
        'transition_progress': 'list[str]',
        'health_state': 'str',
        'health_indications': 'list[str]',
        'system_time': 'str',
        'ip_address': 'str',
        'directors': 'list[str]',
        'is_local': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'cluster_id': 'cluster_id',
        'island_id': 'island_id',
        'allow_auto_join': 'allow_auto_join',
        'connected': 'connected',
        'top_level_assembly': 'top_level_assembly',
        'operational_status': 'operational_status',
        'transition_indications': 'transition_indications',
        'transition_progress': 'transition_progress',
        'health_state': 'health_state',
        'health_indications': 'health_indications',
        'system_time': 'system_time',
        'ip_address': 'ip_address',
        'directors': 'directors',
        'is_local': 'is_local'
    }

    def __init__(self, name=None, cluster_id=None, island_id=None, allow_auto_join=None, connected=None, top_level_assembly=None, operational_status=None, transition_indications=None, transition_progress=None, health_state=None, health_indications=None, system_time=None, ip_address=None, directors=None, is_local=None):  # noqa: E501
        """Cluster - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._cluster_id = None
        self._island_id = None
        self._allow_auto_join = None
        self._connected = None
        self._top_level_assembly = None
        self._operational_status = None
        self._transition_indications = None
        self._transition_progress = None
        self._health_state = None
        self._health_indications = None
        self._system_time = None
        self._ip_address = None
        self._directors = None
        self._is_local = None
        self.discriminator = None

        self.name = name
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if island_id is not None:
            self.island_id = island_id
        if allow_auto_join is not None:
            self.allow_auto_join = allow_auto_join
        if connected is not None:
            self.connected = connected
        if top_level_assembly is not None:
            self.top_level_assembly = top_level_assembly
        if operational_status is not None:
            self.operational_status = operational_status
        if transition_indications is not None:
            self.transition_indications = transition_indications
        if transition_progress is not None:
            self.transition_progress = transition_progress
        if health_state is not None:
            self.health_state = health_state
        if health_indications is not None:
            self.health_indications = health_indications
        if system_time is not None:
            self.system_time = system_time
        if ip_address is not None:
            self.ip_address = ip_address
        if directors is not None:
            self.directors = directors
        if is_local is not None:
            self.is_local = is_local

    @property
    def name(self):
        """Gets the name of this Cluster.  # noqa: E501


        :return: The name of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Cluster.


        :param name: The name of this Cluster.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def cluster_id(self):
        """Gets the cluster_id of this Cluster.  # noqa: E501


        :return: The cluster_id of this Cluster.  # noqa: E501
        :rtype: float
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this Cluster.


        :param cluster_id: The cluster_id of this Cluster.  # noqa: E501
        :type: float
        """

        self._cluster_id = cluster_id

    @property
    def island_id(self):
        """Gets the island_id of this Cluster.  # noqa: E501


        :return: The island_id of this Cluster.  # noqa: E501
        :rtype: float
        """
        return self._island_id

    @island_id.setter
    def island_id(self, island_id):
        """Sets the island_id of this Cluster.


        :param island_id: The island_id of this Cluster.  # noqa: E501
        :type: float
        """

        self._island_id = island_id

    @property
    def allow_auto_join(self):
        """Gets the allow_auto_join of this Cluster.  # noqa: E501


        :return: The allow_auto_join of this Cluster.  # noqa: E501
        :rtype: bool
        """
        return self._allow_auto_join

    @allow_auto_join.setter
    def allow_auto_join(self, allow_auto_join):
        """Sets the allow_auto_join of this Cluster.


        :param allow_auto_join: The allow_auto_join of this Cluster.  # noqa: E501
        :type: bool
        """

        self._allow_auto_join = allow_auto_join

    @property
    def connected(self):
        """Gets the connected of this Cluster.  # noqa: E501


        :return: The connected of this Cluster.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this Cluster.


        :param connected: The connected of this Cluster.  # noqa: E501
        :type: bool
        """

        self._connected = connected

    @property
    def top_level_assembly(self):
        """Gets the top_level_assembly of this Cluster.  # noqa: E501


        :return: The top_level_assembly of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._top_level_assembly

    @top_level_assembly.setter
    def top_level_assembly(self, top_level_assembly):
        """Sets the top_level_assembly of this Cluster.


        :param top_level_assembly: The top_level_assembly of this Cluster.  # noqa: E501
        :type: str
        """

        self._top_level_assembly = top_level_assembly

    @property
    def operational_status(self):
        """Gets the operational_status of this Cluster.  # noqa: E501


        :return: The operational_status of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this Cluster.


        :param operational_status: The operational_status of this Cluster.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def transition_indications(self):
        """Gets the transition_indications of this Cluster.  # noqa: E501


        :return: The transition_indications of this Cluster.  # noqa: E501
        :rtype: list[str]
        """
        return self._transition_indications

    @transition_indications.setter
    def transition_indications(self, transition_indications):
        """Sets the transition_indications of this Cluster.


        :param transition_indications: The transition_indications of this Cluster.  # noqa: E501
        :type: list[str]
        """

        self._transition_indications = transition_indications

    @property
    def transition_progress(self):
        """Gets the transition_progress of this Cluster.  # noqa: E501


        :return: The transition_progress of this Cluster.  # noqa: E501
        :rtype: list[str]
        """
        return self._transition_progress

    @transition_progress.setter
    def transition_progress(self, transition_progress):
        """Sets the transition_progress of this Cluster.


        :param transition_progress: The transition_progress of this Cluster.  # noqa: E501
        :type: list[str]
        """

        self._transition_progress = transition_progress

    @property
    def health_state(self):
        """Gets the health_state of this Cluster.  # noqa: E501


        :return: The health_state of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this Cluster.


        :param health_state: The health_state of this Cluster.  # noqa: E501
        :type: str
        """

        self._health_state = health_state

    @property
    def health_indications(self):
        """Gets the health_indications of this Cluster.  # noqa: E501


        :return: The health_indications of this Cluster.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this Cluster.


        :param health_indications: The health_indications of this Cluster.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def system_time(self):
        """Gets the system_time of this Cluster.  # noqa: E501


        :return: The system_time of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._system_time

    @system_time.setter
    def system_time(self, system_time):
        """Sets the system_time of this Cluster.


        :param system_time: The system_time of this Cluster.  # noqa: E501
        :type: str
        """

        self._system_time = system_time

    @property
    def ip_address(self):
        """Gets the ip_address of this Cluster.  # noqa: E501


        :return: The ip_address of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this Cluster.


        :param ip_address: The ip_address of this Cluster.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def directors(self):
        """Gets the directors of this Cluster.  # noqa: E501


        :return: The directors of this Cluster.  # noqa: E501
        :rtype: list[str]
        """
        return self._directors

    @directors.setter
    def directors(self, directors):
        """Sets the directors of this Cluster.


        :param directors: The directors of this Cluster.  # noqa: E501
        :type: list[str]
        """

        self._directors = directors

    @property
    def is_local(self):
        """Gets the is_local of this Cluster.  # noqa: E501


        :return: The is_local of this Cluster.  # noqa: E501
        :rtype: bool
        """
        return self._is_local

    @is_local.setter
    def is_local(self, is_local):
        """Sets the is_local of this Cluster.


        :param is_local: The is_local of this Cluster.  # noqa: E501
        :type: bool
        """

        self._is_local = is_local

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cluster):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.storage_array_family import StorageArrayFamily  # noqa: F401,E501
from vplexapi.models.storage_volume_itls import StorageVolumeItls  # noqa: F401,E501


class StorageVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'application_consistent': 'bool',
        'block_count': 'int',
        'block_size': 'int',
        'capacity': 'int',
        'health_indications': 'list[str]',
        'health_state': 'str',
        'name': 'str',
        'operational_status': 'str',
        'io_status': 'str',
        'itls': 'list[StorageVolumeItls]',
        'largest_free_chunk': 'int',
        'provision_type': 'str',
        'storage_array_family': 'StorageArrayFamily',
        'storage_array_name': 'str',
        'storage_volumetype': 'str',
        'system_id': 'str',
        'thin_capable': 'bool',
        'thin_rebuild': 'bool',
        'use': 'str',
        'used_by': 'list[str]',
        'vendor_specific_name': 'str'
    }

    attribute_map = {
        'application_consistent': 'application_consistent',
        'block_count': 'block_count',
        'block_size': 'block_size',
        'capacity': 'capacity',
        'health_indications': 'health_indications',
        'health_state': 'health_state',
        'name': 'name',
        'operational_status': 'operational_status',
        'io_status': 'io_status',
        'itls': 'itls',
        'largest_free_chunk': 'largest_free_chunk',
        'provision_type': 'provision_type',
        'storage_array_family': 'storage_array_family',
        'storage_array_name': 'storage_array_name',
        'storage_volumetype': 'storage_volumetype',
        'system_id': 'system_id',
        'thin_capable': 'thin_capable',
        'thin_rebuild': 'thin_rebuild',
        'use': 'use',
        'used_by': 'used_by',
        'vendor_specific_name': 'vendor_specific_name'
    }

    def __init__(self, application_consistent=None, block_count=None, block_size=None, capacity=None, health_indications=None, health_state=None, name=None, operational_status=None, io_status=None, itls=None, largest_free_chunk=None, provision_type=None, storage_array_family=None, storage_array_name=None, storage_volumetype=None, system_id=None, thin_capable=None, thin_rebuild=None, use=None, used_by=None, vendor_specific_name=None):  # noqa: E501
        """StorageVolume - a model defined in Swagger"""  # noqa: E501

        self._application_consistent = None
        self._block_count = None
        self._block_size = None
        self._capacity = None
        self._health_indications = None
        self._health_state = None
        self._name = None
        self._operational_status = None
        self._io_status = None
        self._itls = None
        self._largest_free_chunk = None
        self._provision_type = None
        self._storage_array_family = None
        self._storage_array_name = None
        self._storage_volumetype = None
        self._system_id = None
        self._thin_capable = None
        self._thin_rebuild = None
        self._use = None
        self._used_by = None
        self._vendor_specific_name = None
        self.discriminator = None

        if application_consistent is not None:
            self.application_consistent = application_consistent
        if block_count is not None:
            self.block_count = block_count
        if block_size is not None:
            self.block_size = block_size
        if capacity is not None:
            self.capacity = capacity
        if health_indications is not None:
            self.health_indications = health_indications
        if health_state is not None:
            self.health_state = health_state
        if name is not None:
            self.name = name
        if operational_status is not None:
            self.operational_status = operational_status
        if io_status is not None:
            self.io_status = io_status
        if itls is not None:
            self.itls = itls
        if largest_free_chunk is not None:
            self.largest_free_chunk = largest_free_chunk
        if provision_type is not None:
            self.provision_type = provision_type
        if storage_array_family is not None:
            self.storage_array_family = storage_array_family
        if storage_array_name is not None:
            self.storage_array_name = storage_array_name
        if storage_volumetype is not None:
            self.storage_volumetype = storage_volumetype
        if system_id is not None:
            self.system_id = system_id
        if thin_capable is not None:
            self.thin_capable = thin_capable
        if thin_rebuild is not None:
            self.thin_rebuild = thin_rebuild
        if use is not None:
            self.use = use
        if used_by is not None:
            self.used_by = used_by
        if vendor_specific_name is not None:
            self.vendor_specific_name = vendor_specific_name

    @property
    def application_consistent(self):
        """Gets the application_consistent of this StorageVolume.  # noqa: E501


        :return: The application_consistent of this StorageVolume.  # noqa: E501
        :rtype: bool
        """
        return self._application_consistent

    @application_consistent.setter
    def application_consistent(self, application_consistent):
        """Sets the application_consistent of this StorageVolume.


        :param application_consistent: The application_consistent of this StorageVolume.  # noqa: E501
        :type: bool
        """

        self._application_consistent = application_consistent

    @property
    def block_count(self):
        """Gets the block_count of this StorageVolume.  # noqa: E501


        :return: The block_count of this StorageVolume.  # noqa: E501
        :rtype: int
        """
        return self._block_count

    @block_count.setter
    def block_count(self, block_count):
        """Sets the block_count of this StorageVolume.


        :param block_count: The block_count of this StorageVolume.  # noqa: E501
        :type: int
        """

        self._block_count = block_count

    @property
    def block_size(self):
        """Gets the block_size of this StorageVolume.  # noqa: E501


        :return: The block_size of this StorageVolume.  # noqa: E501
        :rtype: int
        """
        return self._block_size

    @block_size.setter
    def block_size(self, block_size):
        """Sets the block_size of this StorageVolume.


        :param block_size: The block_size of this StorageVolume.  # noqa: E501
        :type: int
        """

        self._block_size = block_size

    @property
    def capacity(self):
        """Gets the capacity of this StorageVolume.  # noqa: E501


        :return: The capacity of this StorageVolume.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this StorageVolume.


        :param capacity: The capacity of this StorageVolume.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def health_indications(self):
        """Gets the health_indications of this StorageVolume.  # noqa: E501


        :return: The health_indications of this StorageVolume.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this StorageVolume.


        :param health_indications: The health_indications of this StorageVolume.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def health_state(self):
        """Gets the health_state of this StorageVolume.  # noqa: E501


        :return: The health_state of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this StorageVolume.


        :param health_state: The health_state of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._health_state = health_state

    @property
    def name(self):
        """Gets the name of this StorageVolume.  # noqa: E501


        :return: The name of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageVolume.


        :param name: The name of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_status(self):
        """Gets the operational_status of this StorageVolume.  # noqa: E501


        :return: The operational_status of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this StorageVolume.


        :param operational_status: The operational_status of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def io_status(self):
        """Gets the io_status of this StorageVolume.  # noqa: E501


        :return: The io_status of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._io_status

    @io_status.setter
    def io_status(self, io_status):
        """Sets the io_status of this StorageVolume.


        :param io_status: The io_status of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._io_status = io_status

    @property
    def itls(self):
        """Gets the itls of this StorageVolume.  # noqa: E501


        :return: The itls of this StorageVolume.  # noqa: E501
        :rtype: list[StorageVolumeItls]
        """
        return self._itls

    @itls.setter
    def itls(self, itls):
        """Sets the itls of this StorageVolume.


        :param itls: The itls of this StorageVolume.  # noqa: E501
        :type: list[StorageVolumeItls]
        """

        self._itls = itls

    @property
    def largest_free_chunk(self):
        """Gets the largest_free_chunk of this StorageVolume.  # noqa: E501


        :return: The largest_free_chunk of this StorageVolume.  # noqa: E501
        :rtype: int
        """
        return self._largest_free_chunk

    @largest_free_chunk.setter
    def largest_free_chunk(self, largest_free_chunk):
        """Sets the largest_free_chunk of this StorageVolume.


        :param largest_free_chunk: The largest_free_chunk of this StorageVolume.  # noqa: E501
        :type: int
        """

        self._largest_free_chunk = largest_free_chunk

    @property
    def provision_type(self):
        """Gets the provision_type of this StorageVolume.  # noqa: E501


        :return: The provision_type of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._provision_type

    @provision_type.setter
    def provision_type(self, provision_type):
        """Sets the provision_type of this StorageVolume.


        :param provision_type: The provision_type of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._provision_type = provision_type

    @property
    def storage_array_family(self):
        """Gets the storage_array_family of this StorageVolume.  # noqa: E501


        :return: The storage_array_family of this StorageVolume.  # noqa: E501
        :rtype: StorageArrayFamily
        """
        return self._storage_array_family

    @storage_array_family.setter
    def storage_array_family(self, storage_array_family):
        """Sets the storage_array_family of this StorageVolume.


        :param storage_array_family: The storage_array_family of this StorageVolume.  # noqa: E501
        :type: StorageArrayFamily
        """

        self._storage_array_family = storage_array_family

    @property
    def storage_array_name(self):
        """Gets the storage_array_name of this StorageVolume.  # noqa: E501


        :return: The storage_array_name of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._storage_array_name

    @storage_array_name.setter
    def storage_array_name(self, storage_array_name):
        """Sets the storage_array_name of this StorageVolume.


        :param storage_array_name: The storage_array_name of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._storage_array_name = storage_array_name

    @property
    def storage_volumetype(self):
        """Gets the storage_volumetype of this StorageVolume.  # noqa: E501


        :return: The storage_volumetype of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._storage_volumetype

    @storage_volumetype.setter
    def storage_volumetype(self, storage_volumetype):
        """Sets the storage_volumetype of this StorageVolume.


        :param storage_volumetype: The storage_volumetype of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._storage_volumetype = storage_volumetype

    @property
    def system_id(self):
        """Gets the system_id of this StorageVolume.  # noqa: E501


        :return: The system_id of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this StorageVolume.


        :param system_id: The system_id of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    @property
    def thin_capable(self):
        """Gets the thin_capable of this StorageVolume.  # noqa: E501


        :return: The thin_capable of this StorageVolume.  # noqa: E501
        :rtype: bool
        """
        return self._thin_capable

    @thin_capable.setter
    def thin_capable(self, thin_capable):
        """Sets the thin_capable of this StorageVolume.


        :param thin_capable: The thin_capable of this StorageVolume.  # noqa: E501
        :type: bool
        """

        self._thin_capable = thin_capable

    @property
    def thin_rebuild(self):
        """Gets the thin_rebuild of this StorageVolume.  # noqa: E501


        :return: The thin_rebuild of this StorageVolume.  # noqa: E501
        :rtype: bool
        """
        return self._thin_rebuild

    @thin_rebuild.setter
    def thin_rebuild(self, thin_rebuild):
        """Sets the thin_rebuild of this StorageVolume.


        :param thin_rebuild: The thin_rebuild of this StorageVolume.  # noqa: E501
        :type: bool
        """

        self._thin_rebuild = thin_rebuild

    @property
    def use(self):
        """Gets the use of this StorageVolume.  # noqa: E501


        :return: The use of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._use

    @use.setter
    def use(self, use):
        """Sets the use of this StorageVolume.


        :param use: The use of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._use = use

    @property
    def used_by(self):
        """Gets the used_by of this StorageVolume.  # noqa: E501


        :return: The used_by of this StorageVolume.  # noqa: E501
        :rtype: list[str]
        """
        return self._used_by

    @used_by.setter
    def used_by(self, used_by):
        """Sets the used_by of this StorageVolume.


        :param used_by: The used_by of this StorageVolume.  # noqa: E501
        :type: list[str]
        """

        self._used_by = used_by

    @property
    def vendor_specific_name(self):
        """Gets the vendor_specific_name of this StorageVolume.  # noqa: E501


        :return: The vendor_specific_name of this StorageVolume.  # noqa: E501
        :rtype: str
        """
        return self._vendor_specific_name

    @vendor_specific_name.setter
    def vendor_specific_name(self, vendor_specific_name):
        """Sets the vendor_specific_name of this StorageVolume.


        :param vendor_specific_name: The vendor_specific_name of this StorageVolume.  # noqa: E501
        :type: str
        """

        self._vendor_specific_name = vendor_specific_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.admin_state import AdminState  # noqa: F401,E501
from vplexapi.models.cluster_witness_components import ClusterWitnessComponents  # noqa: F401,E501


class ClusterWitness(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'admin_state': 'AdminState',
        'components': 'list[ClusterWitnessComponents]',
        'private_ip_address': 'str',
        'public_ip_address': 'str'
    }

    attribute_map = {
        'admin_state': 'admin_state',
        'components': 'components',
        'private_ip_address': 'private_ip_address',
        'public_ip_address': 'public_ip_address'
    }

    def __init__(self, admin_state=None, components=None, private_ip_address=None, public_ip_address=None):  # noqa: E501
        """ClusterWitness - a model defined in Swagger"""  # noqa: E501

        self._admin_state = None
        self._components = None
        self._private_ip_address = None
        self._public_ip_address = None
        self.discriminator = None

        if admin_state is not None:
            self.admin_state = admin_state
        if components is not None:
            self.components = components
        if private_ip_address is not None:
            self.private_ip_address = private_ip_address
        if public_ip_address is not None:
            self.public_ip_address = public_ip_address

    @property
    def admin_state(self):
        """Gets the admin_state of this ClusterWitness.  # noqa: E501


        :return: The admin_state of this ClusterWitness.  # noqa: E501
        :rtype: AdminState
        """
        return self._admin_state

    @admin_state.setter
    def admin_state(self, admin_state):
        """Sets the admin_state of this ClusterWitness.


        :param admin_state: The admin_state of this ClusterWitness.  # noqa: E501
        :type: AdminState
        """

        self._admin_state = admin_state

    @property
    def components(self):
        """Gets the components of this ClusterWitness.  # noqa: E501


        :return: The components of this ClusterWitness.  # noqa: E501
        :rtype: list[ClusterWitnessComponents]
        """
        return self._components

    @components.setter
    def components(self, components):
        """Sets the components of this ClusterWitness.


        :param components: The components of this ClusterWitness.  # noqa: E501
        :type: list[ClusterWitnessComponents]
        """

        self._components = components

    @property
    def private_ip_address(self):
        """Gets the private_ip_address of this ClusterWitness.  # noqa: E501


        :return: The private_ip_address of this ClusterWitness.  # noqa: E501
        :rtype: str
        """
        return self._private_ip_address

    @private_ip_address.setter
    def private_ip_address(self, private_ip_address):
        """Sets the private_ip_address of this ClusterWitness.


        :param private_ip_address: The private_ip_address of this ClusterWitness.  # noqa: E501
        :type: str
        """

        self._private_ip_address = private_ip_address

    @property
    def public_ip_address(self):
        """Gets the public_ip_address of this ClusterWitness.  # noqa: E501


        :return: The public_ip_address of this ClusterWitness.  # noqa: E501
        :rtype: str
        """
        return self._public_ip_address

    @public_ip_address.setter
    def public_ip_address(self, public_ip_address):
        """Sets the public_ip_address of this ClusterWitness.


        :param public_ip_address: The public_ip_address of this ClusterWitness.  # noqa: E501
        :type: str
        """

        self._public_ip_address = public_ip_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterWitness):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.jobs_storage_pools import JobsStoragePools  # noqa: F401,E501


class ViasPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'number_of_volumes': 'float',
        'capacity': 'float',
        'base_name': 'str',
        'job_name': 'str',
        'thin': 'bool',
        'storage_pools': 'list[JobsStoragePools]',
        'storage_views': 'list[str]',
        'consistency_group': 'str'
    }

    attribute_map = {
        'number_of_volumes': 'number_of_volumes',
        'capacity': 'capacity',
        'base_name': 'base_name',
        'job_name': 'job_name',
        'thin': 'thin',
        'storage_pools': 'storage_pools',
        'storage_views': 'storage_views',
        'consistency_group': 'consistency_group'
    }

    def __init__(self, number_of_volumes=None, capacity=None, base_name=None, job_name=None, thin=None, storage_pools=None, storage_views=None, consistency_group=None):  # noqa: E501
        """ViasPayload - a model defined in Swagger"""  # noqa: E501

        self._number_of_volumes = None
        self._capacity = None
        self._base_name = None
        self._job_name = None
        self._thin = None
        self._storage_pools = None
        self._storage_views = None
        self._consistency_group = None
        self.discriminator = None

        self.number_of_volumes = number_of_volumes
        self.capacity = capacity
        self.base_name = base_name
        if job_name is not None:
            self.job_name = job_name
        if thin is not None:
            self.thin = thin
        self.storage_pools = storage_pools
        self.storage_views = storage_views
        if consistency_group is not None:
            self.consistency_group = consistency_group

    @property
    def number_of_volumes(self):
        """Gets the number_of_volumes of this ViasPayload.  # noqa: E501

        The number of virtual volumes to provision.   # noqa: E501

        :return: The number_of_volumes of this ViasPayload.  # noqa: E501
        :rtype: float
        """
        return self._number_of_volumes

    @number_of_volumes.setter
    def number_of_volumes(self, number_of_volumes):
        """Sets the number_of_volumes of this ViasPayload.

        The number of virtual volumes to provision.   # noqa: E501

        :param number_of_volumes: The number_of_volumes of this ViasPayload.  # noqa: E501
        :type: float
        """
        if number_of_volumes is None:
            raise ValueError("Invalid value for `number_of_volumes`, must not be `None`")  # noqa: E501

        self._number_of_volumes = number_of_volumes

    @property
    def capacity(self):
        """Gets the capacity of this ViasPayload.  # noqa: E501

        The capacity of each virtual volume, in bytes.   # noqa: E501

        :return: The capacity of this ViasPayload.  # noqa: E501
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this ViasPayload.

        The capacity of each virtual volume, in bytes.   # noqa: E501

        :param capacity: The capacity of this ViasPayload.  # noqa: E501
        :type: float
        """
        if capacity is None:
            raise ValueError("Invalid value for `capacity`, must not be `None`")  # noqa: E501

        self._capacity = capacity

    @property
    def base_name(self):
        """Gets the base_name of this ViasPayload.  # noqa: E501

        The prefix to use when naming each virtual volume.   # noqa: E501

        :return: The base_name of this ViasPayload.  # noqa: E501
        :rtype: str
        """
        return self._base_name

    @base_name.setter
    def base_name(self, base_name):
        """Sets the base_name of this ViasPayload.

        The prefix to use when naming each virtual volume.   # noqa: E501

        :param base_name: The base_name of this ViasPayload.  # noqa: E501
        :type: str
        """
        if base_name is None:
            raise ValueError("Invalid value for `base_name`, must not be `None`")  # noqa: E501

        self._base_name = base_name

    @property
    def job_name(self):
        """Gets the job_name of this ViasPayload.  # noqa: E501

        The name for the provisioning job. If omitted a random name is generated.   # noqa: E501

        :return: The job_name of this ViasPayload.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this ViasPayload.

        The name for the provisioning job. If omitted a random name is generated.   # noqa: E501

        :param job_name: The job_name of this ViasPayload.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def thin(self):
        """Gets the thin of this ViasPayload.  # noqa: E501

        Whether the virtual volumes and all underlying storage should be thin provisioned.   # noqa: E501

        :return: The thin of this ViasPayload.  # noqa: E501
        :rtype: bool
        """
        return self._thin

    @thin.setter
    def thin(self, thin):
        """Sets the thin of this ViasPayload.

        Whether the virtual volumes and all underlying storage should be thin provisioned.   # noqa: E501

        :param thin: The thin of this ViasPayload.  # noqa: E501
        :type: bool
        """

        self._thin = thin

    @property
    def storage_pools(self):
        """Gets the storage_pools of this ViasPayload.  # noqa: E501


        :return: The storage_pools of this ViasPayload.  # noqa: E501
        :rtype: list[JobsStoragePools]
        """
        return self._storage_pools

    @storage_pools.setter
    def storage_pools(self, storage_pools):
        """Sets the storage_pools of this ViasPayload.


        :param storage_pools: The storage_pools of this ViasPayload.  # noqa: E501
        :type: list[JobsStoragePools]
        """
        if storage_pools is None:
            raise ValueError("Invalid value for `storage_pools`, must not be `None`")  # noqa: E501

        self._storage_pools = storage_pools

    @property
    def storage_views(self):
        """Gets the storage_views of this ViasPayload.  # noqa: E501


        :return: The storage_views of this ViasPayload.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_views

    @storage_views.setter
    def storage_views(self, storage_views):
        """Sets the storage_views of this ViasPayload.


        :param storage_views: The storage_views of this ViasPayload.  # noqa: E501
        :type: list[str]
        """
        if storage_views is None:
            raise ValueError("Invalid value for `storage_views`, must not be `None`")  # noqa: E501

        self._storage_views = storage_views

    @property
    def consistency_group(self):
        """Gets the consistency_group of this ViasPayload.  # noqa: E501

        Which consistency group the virtual volumes will be added to.   # noqa: E501

        :return: The consistency_group of this ViasPayload.  # noqa: E501
        :rtype: str
        """
        return self._consistency_group

    @consistency_group.setter
    def consistency_group(self, consistency_group):
        """Sets the consistency_group of this ViasPayload.

        Which consistency group the virtual volumes will be added to.   # noqa: E501

        :param consistency_group: The consistency_group of this ViasPayload.  # noqa: E501
        :type: str
        """

        self._consistency_group = consistency_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ViasPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class VirtualVolumePayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tier': 'str',
        'thin': 'bool',
        'init': 'bool',
        'device': 'str'
    }

    attribute_map = {
        'tier': 'tier',
        'thin': 'thin',
        'init': 'init',
        'device': 'device'
    }

    def __init__(self, tier=None, thin=None, init=None, device=None):  # noqa: E501
        """VirtualVolumePayload - a model defined in Swagger"""  # noqa: E501

        self._tier = None
        self._thin = None
        self._init = None
        self._device = None
        self.discriminator = None

        if tier is not None:
            self.tier = tier
        if thin is not None:
            self.thin = thin
        if init is not None:
            self.init = init
        self.device = device

    @property
    def tier(self):
        """Gets the tier of this VirtualVolumePayload.  # noqa: E501


        :return: The tier of this VirtualVolumePayload.  # noqa: E501
        :rtype: str
        """
        return self._tier

    @tier.setter
    def tier(self, tier):
        """Sets the tier of this VirtualVolumePayload.


        :param tier: The tier of this VirtualVolumePayload.  # noqa: E501
        :type: str
        """

        self._tier = tier

    @property
    def thin(self):
        """Gets the thin of this VirtualVolumePayload.  # noqa: E501


        :return: The thin of this VirtualVolumePayload.  # noqa: E501
        :rtype: bool
        """
        return self._thin

    @thin.setter
    def thin(self, thin):
        """Sets the thin of this VirtualVolumePayload.


        :param thin: The thin of this VirtualVolumePayload.  # noqa: E501
        :type: bool
        """

        self._thin = thin

    @property
    def init(self):
        """Gets the init of this VirtualVolumePayload.  # noqa: E501


        :return: The init of this VirtualVolumePayload.  # noqa: E501
        :rtype: bool
        """
        return self._init

    @init.setter
    def init(self, init):
        """Sets the init of this VirtualVolumePayload.


        :param init: The init of this VirtualVolumePayload.  # noqa: E501
        :type: bool
        """

        self._init = init

    @property
    def device(self):
        """Gets the device of this VirtualVolumePayload.  # noqa: E501


        :return: The device of this VirtualVolumePayload.  # noqa: E501
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this VirtualVolumePayload.


        :param device: The device of this VirtualVolumePayload.  # noqa: E501
        :type: str
        """
        if device is None:
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VirtualVolumePayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
